COLORS = {}
# Reset
COLORS["reset"] = "\033[0m"  # Text Reset
# Clear
COLORS["clear"] = "\x1b[2J\x1b[H"
# Regular Colors
COLORS["black"] = "\033[0;30m"  # Black
COLORS["red"] = "\033[0;31m"  # Red
COLORS["green"] = "\033[0;32m"  # Green
COLORS["yellow"] = "\033[0;33m"  # Yellow
COLORS["blue"] = "\033[0;34m"  # Blue
COLORS["purple"] = "\033[0;35m"  # Purple
COLORS["cyan"] = "\033[0;36m"  # Cyan
COLORS["white"] = "\033[0;37m"  # White

# Bold
COLORS["bold_black"] = "\033[1;30m"  # Black
COLORS["bold_red"] = "\033[1;31m"  # Red
COLORS["bold_green"] = "\033[1;32m"  # Green
COLORS["bold_yellow"] = "\033[1;33m"  # Yellow
COLORS["bold_blue"] = "\033[1;34m"  # Blue
COLORS["bold_purple"] = "\033[1;35m"  # Purple
COLORS["bold_cyan"] = "\033[1;36m"  # Cyan
COLORS["bold_white"] = "\033[1;37m"  # White

# Underline
COLORS["underline_black"] = "\033[4;30m"  # Black
COLORS["underline_red"] = "\033[4;31m"  # Red
COLORS["underline_green"] = "\033[4;32m"  # Green
COLORS["underline_yellow"] = "\033[4;33m"  # Yellow
COLORS["underline_blue"] = "\033[4;34m"  # Blue
COLORS["underline_purple"] = "\033[4;35m"  # Purple
COLORS["underline_cyan"] = "\033[4;36m"  # Cyan
COLORS["underline_white"] = "\033[4;37m"  # White

# Background
COLORS["background_black"] = "\033[40m"  # Black
COLORS["background_red"] = "\033[41m"  # Red
COLORS["background_green"] = "\033[42m"  # Green
COLORS["background_yellow"] = "\033[43m"  # Yellow
COLORS["background_blue"] = "\033[44m"  # Blue
COLORS["background_purple"] = "\033[45m"  # Purple
COLORS["background_cyan"] = "\033[46m"  # Cyan
COLORS["background_white"] = "\033[47m"  # White

# High Intensity
COLORS["intense_black"] = "\033[0;90m"  # Black
COLORS["intense_red"] = "\033[0;91m"  # Red
COLORS["intense_green"] = "\033[0;92m"  # Green
COLORS["intense_yellow"] = "\033[0;93m"  # Yellow
COLORS["intense_blue"] = "\033[0;94m"  # Blue
COLORS["intense_purple"] = "\033[0;95m"  # Purple
COLORS["intense_cyan"] = "\033[0;96m"  # Cyan
COLORS["intense_white"] = "\033[0;97m"  # White

# Bold High Intensity
COLORS["intense_bold_black"] = "\033[1;90m"  # Black
COLORS["intense_bold_red"] = "\033[1;91m"  # Red
COLORS["intense_bold_green"] = "\033[1;92m"  # Green
COLORS["intense_bold_yellow"] = "\033[1;93m"  # Yellow
COLORS["intense_bold_blue"] = "\033[1;94m"  # Blue
COLORS["intense_bold_purple"] = "\033[1;95m"  # Purple
COLORS["intense_bold_cyan"] = "\033[1;96m"  # Cyan
COLORS["intense_bold_white"] = "\033[1;97m"  # White

# High Intensity backgrounds
COLORS["intense_background_black"] = "\033[0;100m"  # Black
COLORS["intense_background_red"] = "\033[0;101m"  # Red
COLORS["intense_background_green"] = "\033[0;102m"  # Green
COLORS["intense_background_yellow"] = "\033[0;103m"  # Yellow
COLORS["intense_background_blue"] = "\033[0;104m"  # Blue
COLORS["intense_background_purple"] = "\033[0;105m"  # Purple
COLORS["intense_background_cyan"] = "\033[0;106m"  # Cyan
COLORS["intense_background_white"] = "\033[0;107m"  # White

class AttrDict(dict):
    def __getattr__(self, name):
        try:
            return self[name]
        except KeyError:
            raise AttributeError(f"No such attribute: {name}")

    def __setattr__(self, name, value):
        self[name] = value

    def __delattr__(self, name):
        try:
            del self[name]
        except KeyError:
            raise AttributeError(f"No such attribute: {name}")

colors = AttrDict(COLORS)


#! env python
# -*- coding: UTF-8 -*-
from __future__ import print_function

from typing import Optional

import typer

import swag
from swag import colors
from swag.colors import COLORS

TYPE_MODIFIERS = ['underline', 'background', 'bold', 'intense', 'intenseBold', 'intenseBackground']
COLOR_MODIFIERS = ['black', 'red', 'green', 'yellow', 'blue', 'purple', 'cyan', 'white']

app = typer.Typer(
    name="swag",
)


@app.command(
    name="install",
)
def install_handler(dest: Optional[str] = None):
    from swag.install import install
    install(dest)


@app.command(
    name="print",
)
def print_handler(
        text: str,
        reset: bool = True,
        color: str = "white",
        modifier: str = "normal",
):
    swag.swag(color, text, modifier=modifier, continuous=not reset)


@app.command(
    name="list",
)
def list_handler():
    c = COLORS
    for i, key in enumerate(c):
        print(colors.reset + c[key] + key + colors.reset)


if __name__ == '__main__':
    app()



# -*- coding: UTF-8 -*-
import os

from swag import colors


def install(dest=None):
    directory = dest
    if not dest:
        directory = os.environ.get("HOME", os.path.expanduser("~")) + "/.colors"

    c = colors.COLORS

    if not os.path.exists(directory):
        os.makedirs(directory)

    for i, key in enumerate(c):
        print(c["reset"] + c[key] + "Installed " + directory + "/" + key + c["reset"])
        with open(directory + "/" + key, "w") as file:
            file.write(c[key])



from sys import stdout

from swag import colors

BOLD = "bold"
UNDERLINE = "underline"
BACKGROUND = "background"

INTENSE = "intense"
INTENSE_BOLD = "intense_bold"
INTENSE_BACKGROUND = "intense_background"


def swag(color_name, content, modifier=None, continuous=False, file=stdout):
    """
    Swag prints colored text to the console.
    The following colors are available:
    - black
    - yellow
    - green
    - red
    - blue
    - purple
    - white
    - cyan

    Also available are the following modifiers:
    - bold
    - underline
    - background
    - intense
    - intense_bold
    - intense_background

    The color_name and modifier are case-insensitive.

    :param color_name:
    :param content:
    :param modifier:
    :param continuous:
    :param file:
    :return:
    """
    if modifier is not None:
        color_name = "_".join([modifier.lower(), color_name.lower()])

    color = colors.COLORS[color_name]

    text = (
        f"{color}{content}"
        if continuous
        else f"{color}{content}{colors.COLORS['reset']}"
    )

    print(text, file=file)


def black(content, modifier=None, continuous=False, file=stdout):
    swag("black", content, modifier, continuous, file=file)


def yellow(content, modifier=None, continuous=False, file=stdout):
    swag("yellow", content, modifier, continuous, file=file)


def green(content, modifier=None, continuous=False, file=stdout):
    swag("green", content, modifier, continuous, file=file)


def red(content, modifier=None, continuous=False, file=stdout):
    swag("red", content, modifier, continuous, file=file)


def blue(content, modifier=None, continuous=False, file=stdout):
    swag("blue", content, modifier, continuous, file=file)


def purple(content, modifier=None, continuous=False, file=stdout):
    swag("purple", content, modifier, continuous, file=file)


def white(content, modifier=None, continuous=False, file=stdout):
    swag("white", content, modifier, continuous, file=file)


def cyan(content, modifier=None, continuous=False, file=stdout):
    swag("cyan", content, modifier, continuous, file=file)


def reset():
    print(colors.COLORS["reset"])


def clear():
    print(colors.COLORS["clear"])



from swag.colors import colors
from swag.swaggy import (
    swag,
    black,
    yellow,
    green,
    red,
    blue,
    purple,
    white,
    cyan,
    reset,
    clear,
    BOLD,
    UNDERLINE,
    BACKGROUND,
    INTENSE,
    INTENSE_BOLD,
    INTENSE_BACKGROUND,
)

__all__ = [
    "swag",
    "black",
    "yellow",
    "green",
    "red",
    "blue",
    "purple",
    "white",
    "cyan",
    "reset",
    "clear",
    "colors",
    "BOLD",
    "UNDERLINE",
    "BACKGROUND",
    "INTENSE",
    "INTENSE_BOLD",
    "INTENSE_BACKGROUND",
    "colors"
]
